wallaroo.wallaroo_ml_ops_api_client.models.assays_filter_json_body_drift_window API documentation

# wallaroo.wallaroo_ml_ops_api_client.models.assays_filter_json_body_drift_window

View Source

     1import datetime
     2from typing import Any, Dict, List, Type, TypeVar
     3
     4import attr
     5from dateutil.parser import isoparse
     6
     7T = TypeVar("T", bound="AssaysFilterJsonBodyDriftWindow")
     8
     9@attr.s(auto_attribs=True)
    10class AssaysFilterJsonBodyDriftWindow:
    11    """
    12    Attributes:
    13        start (datetime.datetime):
    14        end (datetime.datetime):
    15    """
    16
    17    start: datetime.datetime
    18    end: datetime.datetime
    19    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    20
    21
    22    def to_dict(self) -> Dict[str, Any]:
    23        start = self.start.isoformat()
    24
    25        end = self.end.isoformat()
    26
    27
    28        field_dict: Dict[str, Any] = {}
    29        field_dict.update(self.additional_properties)
    30        field_dict.update({
    31            "start": start,
    32            "end": end,
    33        })
    34
    35        return field_dict
    36
    37
    38
    39    @classmethod
    40    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    41        d = src_dict.copy()
    42        start = isoparse(d.pop("start"))
    43
    44
    45
    46
    47        end = isoparse(d.pop("end"))
    48
    49
    50
    51
    52        assays_filter_json_body_drift_window = cls(
    53            start=start,
    54            end=end,
    55        )
    56
    57        assays_filter_json_body_drift_window.additional_properties = d
    58        return assays_filter_json_body_drift_window
    59
    60    @property
    61    def additional_keys(self) -> List[str]:
    62        return list(self.additional_properties.keys())
    63
    64    def __getitem__(self, key: str) -> Any:
    65        return self.additional_properties[key]
    66
    67    def __setitem__(self, key: str, value: Any) -> None:
    68        self.additional_properties[key] = value
    69
    70    def __delitem__(self, key: str) -> None:
    71        del self.additional_properties[key]
    72
    73    def __contains__(self, key: str) -> bool:
    74        return key in self.additional_properties

@attr.s(auto_attribs=True)
class AssaysFilterJsonBodyDriftWindow: View Source

    10@attr.s(auto_attribs=True)
    11class AssaysFilterJsonBodyDriftWindow:
    12    """
    13    Attributes:
    14        start (datetime.datetime):
    15        end (datetime.datetime):
    16    """
    17
    18    start: datetime.datetime
    19    end: datetime.datetime
    20    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    21
    22
    23    def to_dict(self) -> Dict[str, Any]:
    24        start = self.start.isoformat()
    25
    26        end = self.end.isoformat()
    27
    28
    29        field_dict: Dict[str, Any] = {}
    30        field_dict.update(self.additional_properties)
    31        field_dict.update({
    32            "start": start,
    33            "end": end,
    34        })
    35
    36        return field_dict
    37
    38
    39
    40    @classmethod
    41    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    42        d = src_dict.copy()
    43        start = isoparse(d.pop("start"))
    44
    45
    46
    47
    48        end = isoparse(d.pop("end"))
    49
    50
    51
    52
    53        assays_filter_json_body_drift_window = cls(
    54            start=start,
    55            end=end,
    56        )
    57
    58        assays_filter_json_body_drift_window.additional_properties = d
    59        return assays_filter_json_body_drift_window
    60
    61    @property
    62    def additional_keys(self) -> List[str]:
    63        return list(self.additional_properties.keys())
    64
    65    def __getitem__(self, key: str) -> Any:
    66        return self.additional_properties[key]
    67
    68    def __setitem__(self, key: str, value: Any) -> None:
    69        self.additional_properties[key] = value
    70
    71    def __delitem__(self, key: str) -> None:
    72        del self.additional_properties[key]
    73
    74    def __contains__(self, key: str) -> bool:
    75        return key in self.additional_properties

Attributes: start (datetime.datetime): end (datetime.datetime):

AssaysFilterJsonBodyDriftWindow(start: datetime.datetime, end: datetime.datetime) View Source

    2def __init__(self, start, end):
    3    self.start = start
    4    self.end = end
    5    self.additional_properties = __attr_factory_additional_properties()

Method generated by attrs for class AssaysFilterJsonBodyDriftWindow.

def to_dict(self) -> Dict[str, Any]: View Source

    23    def to_dict(self) -> Dict[str, Any]:
    24        start = self.start.isoformat()
    25
    26        end = self.end.isoformat()
    27
    28
    29        field_dict: Dict[str, Any] = {}
    30        field_dict.update(self.additional_properties)
    31        field_dict.update({
    32            "start": start,
    33            "end": end,
    34        })
    35
    36        return field_dict

@classmethod
def from_dict(cls: Type[~T], src_dict: Dict[str, Any]) -> ~T: View Source

    40    @classmethod
    41    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    42        d = src_dict.copy()
    43        start = isoparse(d.pop("start"))
    44
    45
    46
    47
    48        end = isoparse(d.pop("end"))
    49
    50
    51
    52
    53        assays_filter_json_body_drift_window = cls(
    54            start=start,
    55            end=end,
    56        )
    57
    58        assays_filter_json_body_drift_window.additional_properties = d
    59        return assays_filter_json_body_drift_window

additional_keys: List[str]